@@ -1,9 +1,11 @@
+import { createNode, CreateNodeContext } from '../doc/createNode.js'
 import type { BlockSequence, FlowCollection } from '../parse/cst.js'
 import type { Schema } from '../schema/Schema.js'
 import type { StringifyContext } from '../stringify/stringify.js'
 import { stringifyCollection } from '../stringify/stringifyCollection.js'
 import { Collection } from './Collection.js'
-import { isScalar, ParsedNode, Range, SEQ } from './Node.js'
+import { isScalar, SEQ } from './identity.js'
+import type { ParsedNode, Range } from './Node.js'
 import type { Pair } from './Pair.js'
 import { isScalarValue, Scalar } from './Scalar.js'
 import { toJS, ToJSContext } from './toJS.js'
@@ -115,6 +117,22 @@ export class YAMLSeq<T = unknown> extends Collection {
       onComment
     })
   }
+
+  static from(schema: Schema, obj: unknown, ctx: CreateNodeContext) {
+    const { replacer } = ctx
+    const seq = new this(schema)
+    if (obj && Symbol.iterator in Object(obj)) {
+      let i = 0
+      for (let it of obj as Iterable<unknown>) {
+        if (typeof replacer === 'function') {
+          const key = obj instanceof Set ? it : String(i++)
+          it = replacer.call(obj, key, it)
+        }
+        seq.items.push(createNode(it, undefined, ctx))
+      }
+    }
+    return seq
+  }
 }
 
 function asItemIndex(key: unknown): number | null {
