@@ -106,6 +106,18 @@ describe('tags', () => {
         expect(doc.errors[0].code).toBe('MISSING_CHAR')
       })
     }
+
+    test('malformed URI (eemeli/yaml#498)', () => {
+      const doc = parseDocument('!!%ee 0')
+      expect(doc.errors).toHaveLength(1)
+      expect(doc.errors[0].message).toMatch('URIError')
+    })
+
+    test('CR in tag shorthand (eemeli/yaml#501', () => {
+      const doc = parseDocument(': | !\r!')
+      const err = doc.errors.find(err => err.code === 'TAG_RESOLVE_FAILED')
+      expect(err).not.toBeFalsy()
+    })
   })
 
   test('eemeli/yaml#97', () => {
